# SIGULS-GUI

This Python package contains the GUI for interacting with the Signal Generator for User-Specified Laboratory Signals (SIGULS). 

## Installation

To install the SIGULS-GUI through pip, use the following command:

`pip install siguls-gui`

## Opening the GUI

Open a terminal/command prompt with access to the Python PATH and type:

`siguls-gui`
